package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````C"%```````!``````````+#3````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````,2^````````Q+X`````````
M`"````````$````&````\,T```````#PS6```````/#-8```````<`0`````
M``#8%```````````(````````@````8````(S@````````C.8```````",Y@
M``````#P`0```````/`!````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````6+@```````!8N$```````%BX0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````/#-````````\,U@``````#PS6``
M`````!`"````````$`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````&`````0`
M```4`````P```$=.50"?_[LT[Z@'#Q83ZH7:LD01_F,=HQ$```!&````!```
M``@````@'!``!4`$ABH"0`"0A@&HPBD`($D@!`NXHCA%N@0""D8```!'````
M2P```%````!1````5P```%D```!;````7P```&$`````````8P```&8```!G
M````:```````````````>_!*:V[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#GQ!
MCL6XC?$.U634?-EQ6!SB1\8!K$OCP+KCDGS"Y3\L^J%L8+,!BV]J"4/6A_F<
M@6:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`P4XI[)U;)QVLWCGC-BV^T,.I<+
M5J2;EJ?=HVM_J9R;X:<""@J*$%>CX/M)````````````````````````````
M`````````%0!```2`````````````````````````"D"```2````````````
M`````````````*@"```2`````````````````````````'T"```2````````
M`````````````````!$````@`````````````````````````*\"```2````
M`````````````````````#L#```2`````````````````````````-,````2
M`````````````````````````,0"```2`````````````````````````",#
M```2`````````````````````````!L#```2````````````````````````
M`*\````2`````````````````````````/0#```2````````````````````
M`````$\!```2`````````````````````````.<"```2````````````````
M`````````-("```2`````````````````````````)<"```2````````````
M`````````````#0#```2`````````````````````````%@#```2````````
M`````````````````+@!```2`````````````````````````'@!```2````
M`````````````````````-D"```2`````````````````````````.$````2
M``````````````````````````("```2`````````````````````````%8"
M```2`````````````````````````(X"```2````````````````````````
M`)\!```2`````````````````````````&8"```2````````````````````
M`````(4"```2`````````````````````````.\!```2````````````````
M`````````+T"```2`````````````````````````"0"```2````````````
M`````````````(T#```2`````````````````````````(8#```2````````
M`````````````````(8!```2`````````````````````````$L#```2````
M`````````````````````"T````@`````````````````````````/L"```2
M`````````````````````````'@````2``````````````````````````\!
M```2`````````````````````````$("```2````````````````````````
M`/L!```2`````````````````````````+X````2````````````````````
M`````*T!```2`````````````````````````&H````2````````````````
M`````````%D!```2``````````````````````````(#```2````````````
M`````````````.0!```2`````````````````````````!P!```2````````
M`````````````````+4"```2`````````````````````````#@!```2````
M`````````````````````!T"```2`````````````````````````'<#```2
M`````````````````````````%\#```2`````````````````````````,8!
M```2`````````````````````````'\#```2````````````````````````
M`,L"```2`````````````````````````#P````@````````````````````
M`````/,````2`````````````````````````$0#```2````````````````
M`````````)8!```2`````````````````````````!`#```2````````````
M`````````````'@"```2`````````````````````````#H"```2````````
M`````````````````.T"```2`````````````````````````(<````2````
M`````````````````````%`````@`````````````````````````.`"```2
M`````````````````````````&D#```2`````````````````````````-0!
M```2````L!M``````````````````/T#```2``T`X%=```````!O````````
M`,L#```2``X`1%E``````````````````"($```2``T`4$A```````!^"P``
M`````)H#```2``T`@!]````````,`@```````-$#```2``T``$)````````%
M`````````)`$```2``T`$$)```````"S`0```````+T$```2``T`4%A`````
M```Z`````````(H$```2``L``!M``````````````````-D$```2``T`T%-`
M```````(!````````+`#```0`!D`8-)@``````````````````D$```2``T`
MT$-````````D`````````#P$```1``\`4%E````````$`````````+P#```0
M`!D`R.)@`````````````````(@$```2``T`P$!````````J`````````)T$
M```2``T`,$=````````?`0```````*\$```2``T`H$9```````!4````````
M`"\$```0`!@`0-)@`````````````````)X````2````L!Y`````````````
M`````!8$```2``T``$1```````"_`````````)\#```1`!D`<-)@```````(
M`````````*D#```0`!@`8-)@`````````````````*`#```A`!D`<-)@````
M```(`````````'$$```1`!@`6-)@```````(`````````"T#```1`!D`>-)@
M```````(`````````,$#```2``T`0%E````````"`````````&4!```2````
M\!U``````````````````&$$```2``T`L%A```````")`````````#4$```2
M``T`C"%``````````````````#$$```@`!@`0-)@`````````````````"T!
M```1`!D`8-)@```````$`````````*$#```A`!D`<-)@```````(````````
M`.(#```2``T``$=````````D`````````$L$```2``T`0$%```````"Y````
M``````(!```1`!D`:-)@```````!`````````'L$```2``T`P$1```````#;
M`0````````!L:6)P97)L+G-O+C4N,3@`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8G!T:')E
M860N<V\N,`!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`
M<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!L:6)C+G-O+C8`7U]R96=I<W1E
M<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A
M8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I
M9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F
M7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M
M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V
M90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?
M961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U
M<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE
M86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?
M9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?
M:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C
M;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`6%-?26YT97)N86QS
M7U!!4E]"3T]4`$=,24)#7S(N,BXU`$=,24)#7S(N,30`1TQ)0D-?,BXS+C0`
M1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````@`#``(``@````(``@````(``@`"
M`````@````(``@`$``(``@```````@```````P`"````!0`"`````@`#``(`
M`@````8````'```````#``(````````````&```````"`````P`"``(````"
M``(```````(````"``(``P`&```````"``8````!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$````!``(``0`"``$``@`!`````0`!``$````"
M``$``0````$```````$``0`-`@``$````"````!U&FD)```#`.\$````````
M`0`%`%P"```0`````````)21E@8```<`^P0``!````!T&6D)```&``8%```0
M````<AEI"0``!0`2!0``$````!1I:0T```0`'@4``!````!U&FD)```"`.\$
M````````^,]@```````&````)0``````````````8-)@```````%````9```
M````````````:-)@```````%````:```````````````<-)@```````%````
M6@``````````````>-)@```````%````7@``````````````&-!@```````'
M`````0``````````````(-!@```````'`````@``````````````*-!@````
M```'`````P``````````````,-!@```````'````!```````````````.-!@
M```````'````!@``````````````0-!@```````'````!P``````````````
M2-!@```````'````"```````````````4-!@```````'````"0``````````
M````6-!@```````'````1@``````````````8-!@```````'````"@``````
M````````:-!@```````'````"P``````````````<-!@```````'````#```
M````````````>-!@```````'````#0``````````````@-!@```````'````
M#@``````````````B-!@```````'````#P``````````````D-!@```````'
M````$```````````````F-!@```````'````$0``````````````H-!@````
M```'````$@``````````````J-!@```````'````$P``````````````L-!@
M```````'````%```````````````N-!@```````'````%0``````````````
MP-!@```````'````%@``````````````R-!@```````'````%P``````````
M````T-!@```````'````&```````````````V-!@```````'````&0``````
M````````X-!@```````'````&@``````````````Z-!@```````'````&P``
M````````````\-!@```````'````'```````````````^-!@```````'````
M'0```````````````-%@```````'````'@``````````````"-%@```````'
M````'P``````````````$-%@```````'````(```````````````&-%@````
M```'````(0``````````````(-%@```````'````(@``````````````*-%@
M```````'````(P``````````````,-%@```````'````)```````````````
M.-%@```````'````)0``````````````0-%@```````'````)@``````````
M````2-%@```````'````)P``````````````4-%@```````'````*```````
M````````6-%@```````'````*0``````````````8-%@```````'````*@``
M````````````:-%@```````'````*P``````````````<-%@```````'````
M+```````````````>-%@```````'````8```````````````@-%@```````'
M````+0``````````````B-%@```````'````+@``````````````D-%@````
M```'````+P``````````````F-%@```````'````,```````````````H-%@
M```````'````,0``````````````J-%@```````'````,@``````````````
ML-%@```````'````,P``````````````N-%@```````'````-```````````
M````P-%@```````'````-0``````````````R-%@```````'````-@``````
M````````T-%@```````'````-P``````````````V-%@```````'````6```
M````````````X-%@```````'````.```````````````Z-%@```````'````
M.0``````````````\-%@```````'````.P``````````````^-%@```````'
M````/````````````````-)@```````'````/0``````````````"-)@````
M```'````/@``````````````$-)@```````'````/P``````````````&-)@
M```````'````0```````````````(-)@```````'````00``````````````
M*-)@```````'````0@``````````````,-)@```````'````1```````````
M````.-)@```````'````10``````````````2(/L"$B+!>VT(`!(A<!T!>A;
M`@``2(/$",,```````#_->*T(`#_)>2T(``/'T``_R7BM"``:`````#IX/__
M__\EVK0@`&@!````Z=#_____)=*T(`!H`@```.G`_____R7*M"``:`,```#I
ML/____\EPK0@`&@$````Z:#_____);JT(`!H!0```.F0_____R6RM"``:`8`
M``#I@/____\EJK0@`&@'````Z7#_____):*T(`!H"````.E@_____R6:M"``
M:`D```#I4/____\EDK0@`&@*````Z4#_____)8JT(`!H"P```.DP_____R6"
MM"``:`P```#I(/____\E>K0@`&@-````Z1#_____)7*T(`!H#@```.D`____
M_R5JM"``:`\```#I\/[___\E8K0@`&@0````Z>#^____)5JT(`!H$0```.G0
M_O___R52M"``:!(```#IP/[___\E2K0@`&@3````Z;#^____)4*T(`!H%```
M`.F@_O___R4ZM"``:!4```#ID/[___\E,K0@`&@6````Z8#^____)2JT(`!H
M%P```.EP_O___R4BM"``:!@```#I8/[___\E&K0@`&@9````Z5#^____)1*T
M(`!H&@```.E`_O___R4*M"``:!L```#I,/[___\E`K0@`&@<````Z2#^____
M)?JS(`!H'0```.D0_O___R7RLR``:!X```#I`/[___\EZK,@`&@?````Z?#]
M____)>*S(`!H(````.G@_?___R7:LR``:"$```#IT/W___\ETK,@`&@B````
MZ<#]____)<JS(`!H(P```.FP_?___R7"LR``:"0```#IH/W___\ENK,@`&@E
M````Z9#]____);*S(`!H)@```.F`_?___R6JLR``:"<```#I</W___\EHK,@
M`&@H````Z6#]____)9JS(`!H*0```.E0_?___R62LR``:"H```#I0/W___\E
MBK,@`&@K````Z3#]____)8*S(`!H+````.D@_?___R5ZLR``:"T```#I$/W_
M__\E<K,@`&@N````Z0#]____)6JS(`!H+P```.GP_/___R5BLR``:#````#I
MX/S___\E6K,@`&@Q````Z=#\____)5*S(`!H,@```.G`_/___R5*LR``:#,`
M``#IL/S___\E0K,@`&@T````Z:#\____)3JS(`!H-0```.F0_/___R4RLR``
M:#8```#I@/S___\E*K,@`&@W````Z7#\____)2*S(`!H.````.E@_/___R4:
MLR``:#D```#I4/S___\E$K,@`&@Z````Z4#\____)0JS(`!H.P```.DP_/__
M_R4"LR``:#P```#I(/S___\E^K(@`&@]````Z1#\____)?*R(`!H/@```.D`
M_/___R7JLB``:#\```#I\/O___\EXK(@`&A`````Z>#[____)=JR(`!H00``
M`.G0^____R72LB``:$(```#IP/O___\ERK(@`&A#````Z;#[____)<*R(`!H
M1````.F@^___4TB#[#")?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(C50D".CI
M_?__NO`=0`"_L!Y``$B)UNC7.```@#VHLB```'4OZ-G\__](A<!(B07OPB``
M#X2F`0``2(G'Z`'\__^+/7NR(`#HQOW__\:`E0@```"+/6FR(`#HM/W__X"(
MK@0```*+/5>R(`#HHOW__X"(K@0```&+1"0<C7@%2&/_2(7_#X@8`0``\D@/
M*L?R#U@%$Y@``&8/+@43F```#X=$`0``2,'G`^BT_/__2(M,)!!(B050PB``
MQP5.PB``!````$B+$4C'0`@Y6T``2,=`&#Q;0`!(B1!(BQ79L2``2(E0$(M4
M)!R#^@%^)XUR_DR-!/4(````,?8/'X``````2(M\,0A(B7PP($B#Q@A,.<9U
M[8U*!$B+/0/"(`"#P@-%,<"^\$!``$ACR4C'1,CX`````$B)P>A4_?__A<")
MPW0[2(L]U\$@`.AR^___2(UT)"PQP+_]64``Z'$8``!(A<!T*4B+/;7!(`#H
M\/K__^CK_/__2(/$,(G86\-(BSV<P2``Z-?]__^)P^NU2(L]A,$@`$B%_W0D
MZ*(V``#KQ$B)^$B)^DC1Z(/B`4@)T/)(#RK`\@]8P.G0_O__2(UT)"R_LEE`
M`.@$&```2(7`2(D%0L$@`'2,2(G'Z[R_`0```.B9_?__Z-3\__\Q[4F)T5Y(
MB>)(@^3P4%1)Q\!`64``2,?!L%A``$C'QX`?0`#H>_O___1F+@\?A```````
MN&?28`!52"U@TF``2(/X#DB)Y7<"7<.X`````$B%P'3T7;]@TF``_^`/'X``
M````N&#28`!52"U@TF``2,'X`TB)Y4B)PDC!ZC](`=!(T?AU`EW#N@````!(
MA=)T]%U(B<:_8-)@`/_B#Q^``````(`]2;`@``!U$55(B>7H?O___UW&!3:P
M(``!\\,/'T``2(,]J*L@``!T'K@`````2(7`=!15OP#.8`!(B>7_T%WI>___
M_P\?`.ES____#Q\`05=,C4<X,<E!5D%505154TB![!`"``!F#Q^$``````!)
MBQ0(2(G02(G62,'@"$C!YA@E``#_`(GV2`GP2(G62,'N"('F`/\``$@)\$B)
MUDC![AA`#[;V2`GP2(G62,'N($B)1$R(2(GP2,'F&$C!X`B)]B4``/\`2`GP
M2(G62,'J.$C![BB!Y@#_``!("?!("=!(B41,D$B#P0A(@_E`#X5[____2(U$
M)(A(C;0D\`$``$B-4&AF+@\?A```````2(M"V$@S`DB#P@A(,T*@2#-"D$B)
MP4@!P$C!Z1]("<&#X?](B4H02#GR==1(BQ=,BV\@3(M/"$R+5Q!,BV<83(GI
M2(G02`-,)(A(B=9(P>@;3(G-2,'F!4C![0)-B>!("?!,`T0DD$B)UHG`2/?6
M28G63(V<`9EY@EI,B<A,B=%(]]!,(<E,(=9,(>!)P>X"3(G32`G(2`-<))A)
M`<-,B<A(P>`>1(G92`G%B>U(B>A((=!("?!(B<Y-C80`F7F"6DB)R$C![AM(
MP>`%2`G&2(G02,'@'HGV20G&2(G(20'P18GV2/?01(G&32'S2"'H3`G83(V<
M`YEY@EI(B?!(B?-(P>,%2,'H&T@)V$B)RTC!X1Z)P$C!ZP))`<-("<M(`VPD
MH$B)\8G;1(G82/?122'83"'Q3`-T)*A,"<%,C80-F7F"6DB)P4B)Q4C!Y05(
MP>D;2`GI2(GU2,'F'DC![0*)R4@)]4B)QDD!R(GM2/?61(G!2"'>22'K2`-<
M)+!,"=Y-C9PVF7F"6DB)SDF)SDG!Y@5(P>X;3`GV28G&2,'@'DG![@*)]DD)
MQDB)R$D!\T6)]DCWT$2)WDTA\$@AZ$P)P$R-A`.9>8):2(GP2(GS2,'C!4C!
MZ!M("=A(B<M(P>$>B<!(P>L"20'`2`G+2`-L)+A(B?&)VT2)P$CWT4DAVTPA
M\4P#="3`3`G93(V<#9EY@EI(B<%(B<5(P>4%2,'I&T@)Z4B)]4C!YAY(P>T"
MB<E("?5(B<9)`<N)[4CWUD2)V4@AWDDAZ$@#7"3(3`G&38V$-IEY@EI(B<Y)
MB<Y)P>8%2,'N&TP)]DF)QDC!X!Y)P>X"B?9)"<9(B<A)`?!%B?9(]]!$B<9-
M(?-((>A,"=A,C9P#F7F"6DB)\$B)\TC!XP5(P>@;2`G82(G+2,'A'HG`2,'K
M`DD!PT@)RT@#;"302(GQB=M$B=A(]]%)(=A,(?%,`W0DV$P)P4R-A`V9>8):
M2(G!2(G%2,'E!4C!Z1M(">E(B?5(P>8>2,'M`HG)2`GU2(G&20'(B>U(]]9$
MB<%((=Y)(>M(`UPDX$P)WDV-G#:9>8):2(G.28G.2<'F!4C![AM,"?9)B<9(
MP>`>2<'N`HGV20G&2(G(20'S18GV2/?01(G>32'P2"'H3`G`3(V$`YEY@EI(
MB?!(B?-(P>,%2,'H&T@)V$B)RTC!X1Z)P$C!ZP))`<!("<M(`VPDZ$B)\8G;
M1(G`2/?122';3"'Q3`-T)/!,"=E,C9P-F7F"6DB)P4B)Q4C!Y05(P>D;2`GI
M2(GU2,'F'DC![0*)R4@)]4B)QDD!RXGM2/?61(G92"'>22'H2`-<)/A,"<9-
MC80VF7F"6DB)SDF)SDG!Y@5(P>X;3`GV28G&2,'@'DG![@*)]DD)QDB)R$D!
M\$6)]DCWT$2)QDTA\T@AZ$P)V$F)\TB-G`.9>8):2(GP2<'C!4C!Z!M,"=A)
MB<M(P>$>B<!)P>L"2`'#20G+2`,L)$B)\46)VXG82/?132'83"'Q3`-T)`A,
M"<%,C80-F7F"6DB)P4B)Q4C!Y05(P>D;2`GI2(GU2,'F'DC![0*)R4@)]4B)
MQDD!R(GM2/?61(G!3"'>2"'K3`-<)!!("=Y)C9PVF7F"6DB)SDF)SDG!Y@5(
MP>X;3`GV28G&2,'@'DG![@*)]DD)QDB)R$@!\T6)]DCWT(G>32'P2"'H3`G`
M38V$`YEY@EI(B?!)B?-)P>,%2,'H&TP)V$F)RTC!X1Z)P$G!ZP))`<!)"<M(
M`VPD&$B)\46)VT2)P$CWT4PAVTPA\4P#="0@2`G92(G#2(VL#9EY@EI(B<%(
MP>,%2,'I&T@)V8G)2`'-2(GQ2,'F'DC!Z0*)ZT@)\4B)QD&)STCWUDTA^$PA
MWDP#7"0H3`G&28G83`-\)#!-C;0VF7F"6DB)WDG!X`5(P>X;3`G&B?9)`?9(
MB<9(P>`>2,'N`D6)\$@)QDR)P$@Q\4C!Z!LQS4R)P4C!X05)C:PKH>O9;D@)
MR$B)V4C!XQY(P>D"B<!("=E(`<5(B<A!B>M(,?!,B=N)]D$QQDR)V$C!XP5(
MP>@;3XVT-Z'KV6Y(`W0D.$@)V(G`20'&3(G`2<'@'DC!Z`)$B?-,"<!)B<!)
M,<B)R4@#3"1`1#'%28G82(VL+J'KV6Y(B=Y)P>`%2,'N&TP)QHGV2`'U3(G>
M2<'C'DC![@)!B>A,"=Y)B?-),<.)P$@#1"1(13'>38G#3HVT,:'KV6Y,B<%)
MP>,%2,'I&TP)V8G)20'.2(G92,'C'DC!Z0)%B?-("=E(B<M(,?.)]C'=3(G;
M2(VL**'KV6Y,B=A(P>@;2,'C!4@#="102`G8B<!(`<5,B<!)P>`>2,'H`HGK
M3`G`28G`23'(B<E(`TPD6$4QQDF)V$Z-M#:AZ]EN2(G>2<'@!4C![AM,"<:)
M]DD!]DR)WDG!XQY(P>X"18GP3`G>28GS23'#B<!(`T0D8$0QW4V)PTB-K"FA
MZ]EN3(G!2<'C!4C!Z1M,"=F)R4@!S4B)V4C!XQY(P>D"08GK2`G92(G+2#'S
MB?9!,=Y,B=M.C;0PH>O9;DR)V$C!XP5(P>@;2`G8B<!)`<9,B<!(P>@"2<'@
M'D@#="1H3`G`1(GS28G`23'(B<E(`TPD<$0QQ4F)V$B-K"ZAZ]EN2(G>2<'@
M!4C![AM,"<:)]D@!]4R)WDG!XQY(P>X"08GH3`G>28GS23'#B<!(`T0D>$4Q
MWDV)PTZ-M#&AZ]EN3(G!2<'C!4C!Z1M,"=F)R4D!SDB)V4C!XQY(P>D"18GS
M2`G92(G+2#'SB?8QW4R)VTB-K"BAZ]EN3(G82,'C!4C!Z!M("=B)P$@!Q4R)
MP$G!X!Y(P>@"B>M,"<!(`[0D@````$F)P$DQR(G)2`.,)(@```!%,<9)B=A.
MC;0VH>O9;DB)WDG!X`5(P>X;3`G&B?9)`?9,B=Y)P>,>2,'N`D6)\$P)WDF)
M\TDQPXG`2`.$))````!$,=U-B<-(C:PIH>O9;DR)P4G!XP5(P>D;3`G9B<E(
M`<U(B=E(P>,>2,'I`D&)ZT@)V4B)RT@Q\XGV2`.T))@```!!,=Y,B=M.C;0P
MH>O9;DR)V$C!XP5(P>@;2`G8B<!)`<9,B<!)P>`>2,'H`D2)\TP)P$F)P$DQ
MR(G)1#'%28G82(VL+J'KV6Y(B=Y(P>X;2<'@!4@#C"2@````3`G&B?9(`?5,
MB=Y)P>,>2,'N`D&)Z$P)WDF)\TDQPXG`2`.$)*@```!%,=Y-B<-.C;0QH>O9
M;DR)P4G!XP5(P>D;3`G9B<E)`<Y(B=E(P>,>2,'I`D6)\T@)V4B)RT@Q\XGV
M2`.T)+`````QW4R)VTB-K"BAZ]EN3(G82,'C!4C!Z!M("=B)P$@!Q4R)P$G!
MX!Y(P>@"B>M,"<!)B<!),<B)R44QQDF)V$Z-O#:AZ]EN2(G>2<'@!4C![AM,
M"<9-B=B)]DD!]TG!XQY)P>@"30G82`.,)+@```!%B?Y,B<9(,<:)P$@#A"3`
M````,?5,B?9,C9PIH>O9;DR)\4C!Y@5(P>D;2`GQ2(G>2,'C'DC![@*)R4@)
MWDD!RTB)\42)W4PQP46)P$$QSTB)Z4Z-O#BAZ]EN2(GH2,'A!4C!Z!M("<A,
MB?%)P>8>B<!(P>D"20''N-R\&X],"?%)B<9,`[0DR````$2)^TT!\$F)SDD)
M]DTA\TF)SDDA]HGV10GS3XTT&$F)V$F)VTG!XP5)P>@;30G818G`30'&28GH
M2,'E'DG!Z`)%B?-)">A(B<5(`ZPDT````$@![DR)Q4@)S4DA[TR)Q4@AS8G)
M00GO3(G=20'W3(G>2,'E!4C![AM(">Z)]DD!]TB)WDC!XQY(P>X"1(G]2`G>
M2(G#2`.<)-@```!(`=E(B?-,"<-)(=Y(B?-,(<-%B<!!"=Y(B>M)`<Y(B>E(
MP>,%2,'I&T@)V8G)20'.3(G92<'C'DC!Z0)$B?-,"=E)B<-,`YPDX````$T!
MV$F)RTD)\TTAWTF)RTDA\XGV10G?28G;30''28G82<'C!4G!Z!M-"=A%B<!-
M`<=)B>A(P>4>2<'H`D6)^TD)Z$B)Q4@#K"3H````2`'N3(G%2`G-22'N3(G%
M2"'-B<E!">Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C'DC![@)$
MB?5("=Y(B<-(`YPD\````$@!V4B)\TP)PTDAWTB)\TPAPT6)P$$)WTB)ZTD!
MSTB)Z4C!XP5(P>D;2`G9B<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"3X
M````30'828G+20GS32'>28G+22'SB?9%"=Y)B=M-`<9)B=A)P>,%2<'H&TT)
MV$6)P$T!QDF)Z$C!Y1Y)P>@"18GS20GH2(G%2`.L)``!``!(`>Y,B<5("<U)
M(>],B<5((<V)R4$)[TR)W4D!]TR)WDC!Y05(P>X;2`GNB?9)`?=(B=Y(P>X"
M2,'C'D2)_4@)WDB)PT@#G"0(`0``2`'92(GS3`G#22'>2(GS3"'#18G`00G>
M2(GK20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4G!XQY(P>D"1(GS3`G928G#
M3`.<)!`!``!-`=A)B<M)"?--(=])B<M)(?.)]D4)WTF)VTT!QTF)V$G!XP5)
MP>@;30G818G`30''28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPD&`$``$@![DR)
MQ4@)S4DA[DR)Q4@AS8G)00GN3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)
MWDC!XQY(P>X"1(GU2`G>2(G#2`.<)"`!``!(`=E(B?-,"<-)(=](B?-,(<-%
MB<!!"=](B>M)`<](B>E(P>,%2,'I&T@)V8G)20'/3(G92<'C'DC!Z0)$B?M,
M"=E)B<-,`YPD*`$``$T!V$F)RTD)\TTAWDF)RTDA\XGV10G>28G;30'&28G8
M2<'H&TG!XP5-"=A%B<!-`<9)B>A(P>4>2<'H`D6)\TD)Z$B)Q4@#K"0P`0``
M2`'N3(G%2`G-22'O3(G%2"'-B<E!">],B=U)`?=,B=Y(P>4%2,'N&T@)[HGV
M20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPD.`$``$@!V4B)\TP)PTDAWDB)
M\TPAPT6)P$$)WDB)ZTD!SDB)Z4C!XP5(P>D;2`G9B<E)`<Y,B=E(P>D"2<'C
M'D2)\TP)V4F)PTP#G"1``0``30'828G+20GS32'?28G+22'SB?9%"=])B=M-
M`<=)B=A)P>,%2<'H&TT)V$6)P$T!QTF)Z$C!Y1Y)P>@"18G[20GH2(G%2`.L
M)$@!``!(`>Y,B<5("<U)(>Y,B<5((<V)R4$)[DR)W4D!]DR)WDC!Y05(P>X;
M2`GNB?9)`?9(B=Y(P>,>2,'N`D2)]4@)WDB)PT@#G"10`0``2`'92(GS3`G#
M22'?2(GS3"'#18G`00G?2(GK20'/2(GI2,'C!4C!Z1M("=F)R4D!STR)V4G!
MXQY(P>D"1(G[3`G928G#3`.<)%@!``!(`X0D8`$``$T!V$F)RTD)\TTAWDF)
MRTDA\XGV10G>28G;2`'P30'&28G82<'C!4G!Z!M-"=A%B<!-`<9)B>A(P>4>
M2<'H`D6)\TD)Z$R)QD@)SDDA]TR)QD@ASHG)00GW3(G>20''3(G82,'H&TC!
MY@5("?!(B=Y(P>,>B<!(P>X"20''N-;!8LI("=Y(B<-(`YPD:`$``$2)_4@!
MV4B)\TPQPT6)P$$QWDB)ZTD!SDB)Z4C!XP5(P>D;2`G9B<E)`<Y,B=E)P>,>
M2,'I`D2)\TP)V4F)PTP#G"1P`0``30'828G+23'SB?9%,=])B=M-`<=)B=A)
MP>,%2<'H&TT)V$6)P$T!QTF)Z$C!Y1Y)P>@"18G[20GH2(G%2`.L)'@!``!(
M`>Y,B<5(,<V)R4$Q[DR)W4D!]DR)WDC!Y05(P>X;2`GNB?9)`?9(B=Y(P>,>
M2,'N`D2)]4@)WDB)PT@#G"2``0``2`'92(GS3#'#18G`03'?2(GK20'/2(GI
M2,'C!4C!Z1M("=F)R4D!STR)V4G!XQY(P>D"1(G[3`G928G#3`.<)(@!``!-
M`=A)B<M),?.)]D4QWDF)VTT!QDF)V$G!XP5)P>@;30G818G`30'&28GH2,'E
M'DG!Z`)%B?-)">A(B<5(`ZPDD`$``$@![DR)Q4@QS8G)03'O3(G=20'W3(G>
M2,'E!4C![AM(">Z)]DD!]TB)WDC!XQY(P>X"1(G]2`G>2(G#2`.<))@!``!(
M`=E(B?-,,<-%B<!!,=Y(B>M)`<Y(B>E(P>,%2,'I&T@)V8G)20'.3(G92<'C
M'DC!Z0)$B?-,"=E)B<-,`YPDH`$``$T!V$F)RTDQ\XGV13'?28G;30''28G8
M2<'C!4G!Z!M-"=A%B<!-`<=)B>A)P>@"2,'E'D6)^TD)Z$B)Q4@#K"2H`0``
M2`'N3(G%2#'-B<E!,>Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C
M'DC![@)$B?5("=Y(B<-(`YPDL`$``$@!V4B)\TPQPT6)P$$QWTB)ZTD!STB)
MZ4C!XP5(P>D;2`G9B<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"2X`0``
M30'828G+23'SB?9%,=Y)B=M-`<9)B=A)P>@;2<'C!4T)V$6)P$T!QDF)Z$C!
MY1Y)P>@"18GS20GH2(G%2`.L),`!``!(`>Y,B<5(,<V)R4$Q[TR)W4D!]TR)
MWDC!Y05(P>X;2`GNB?9)`?=(B=Y(P>,>2,'N`D2)_4@)WDB)PT@#G"3(`0``
M2`'92(GS3#'#18G`03'>2(GK20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4G!
MXQY(P>D"1(GS3`G928G#3`.<)-`!``!-`=A)B<M),?.)]D4QWTF)VTT!QTF)
MV$G!XP5)P>@;30G818G`30''28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPDV`$`
M`$@![DR)Q4@QS8G)03'N3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)WDC!
MXQY(P>X"1(GU2`G>2(G#2`.<).`!``!(`=E(B?-,,<-%B<!!,=](B>M)`<](
MB>E(P>,%2,'I&T@)V8G)20'/3(G92<'C'DC!Z0)$B?M,"=E)B<-,`YPDZ`$`
M`$T!V$F)RTDQ\XGV13'>28G;30'&28G82<'C!4G!Z!M-"=A%B<!-`<9)B>A(
MP>4>2<'H`D6)\TD)Z$B)Q4@#K"3P`0``2`'N3(G%2#'-B<E!,>],B=U)`?=,
MB=Y(P>4%2,'N&T@)[HGV20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPD^`$`
M`$@!V4B)\TPQPT6)P$$QWDJ-'#%(B>E)B>Y)P>8%2,'I&TP)\0'+3(G92,'I
M`DG!XQY(`X0D``(``$P)V4F)ZTC!Y1Y)P>L"00'920GK2(G=3`'`28G(2,'E
M!4DQ\$0!X40![D4QQT4!VDZ-!#A(B=A(P>@;2`GH1`'``<)(B1=,B4\(3(E7
M$$B)3QA(B7<@2('$$`(``%M=05Q!74%>05_##Q^``````$%7059!54F)_4%4
M55-(@^P(2(7_=&A,BS7CF"``387V=%P/M@=)B?<\/71DA,!T8$F)_$F#Q`%!
M#[8$)#P]=`2$P'7O12GL28L>2(7;="]-8^1,B?4/'P!,B>),B>Y(B=_HBN'_
M_X7`=0="@#PC/70G2(/%"$B+70!(A=MUVDB#Q`@QP%M=05Q!74%>05_#D$4Q
MY.NR#Q\`3"GU2HU$(P%(P?T#08DO2(/$"%M=05Q!74%>05_#9BX/'X0`````
M`%-(B?M(@^P0#Q^$``````!(C70D##'`2(G?Z"'___](A<!T+DAC5"0,2(L%
M$)@@`$B-!-!(BU`(2(722(D0=-!(@\`(2(M0"$B%TDB)$'7PZ[Y(@\006\,/
M'X0``````$%7,<!!5D%5051)B?Q54TB)\TB#[!B`/CT/E,!(`<-(B=_H:>'_
M_TB-="0,28G%3(GG,<#HI_[__TB%P$B)Q0^$^P```$B)Q^A#X?__1(GJ2#G0
M#X//````BVPD#$$/M@0D/#T/A(8!``"$P`^$?@$``$R)XNL-9@\?A```````
MA,ET#$B#P@$/M@J`^3UU\$0IXDB+!4:7(`!"C7PJ`DB-+.CHB.+__TB%P$B)
M10`/A$X!``"+5"0,2(L%()<@`$F-3"0!2(L4T$$/M@0DA,"(`G4>ZR!F+@\?
MA```````2(/!`0^V0?](@\(!A,"(`G0$/#UUZL8"/3'`#Q]$```/M@P#B$P"
M`4B#P`&$R77P,<!(@\086UU!7$%=05Y!7\,/'X``````2(/#`0^V0_](@\4!
MA,"(1?]U[>O3#Q\`3(LUF98@`$F#/@`/A*8```!,B?`Q[68N#Q^$``````!(
M@\`(@\4!2(,X`'7SC74"2&/V2,'F`XL%DZ8@`(7`="],B??H-^+__TB%P$B)
M!4V6(`!T;DQC_4B)P4K'1/D(`````(EL)`SIL/[__P\?`$B)]\<%4Z8@``$`
M``#H;N'__TB%P'0\3&/]3(GV2(G'2HT4_0````#H$^+__TB)P4B)!?F5(`#K
ML@\?@``````QTNF<_O__OA`````Q[>ET____N/_____I!?___P\?`$%50515
M2(G]4TB![)@```!(A?]T!8`_`'462('$F````%M=05Q!7<,/'X0``````.C[
MWO__2(7`28G$=-U,B>?HJ^'__TB%P$B)PP^$GP```(![$RX/A+4```!(@\,3
M2(GOZ!G?__](B=])B<7H#M___T&-?`4"2&/_Z*'@__])B=E)B<5(B<=)B>BY
M5%E``$C'PO____^^`0```#'`Z"WB__^_`0```$B)XDR)[NAMWO__@_C_3(GO
M=!"+1"08)0#P```]`$```'1MZ.#=__],B>_HN-W__TR)Y^@0X?__2(7`2(G#
M#X5E____#Q]``$R)Y^@HW___2(GOZ'#>__](@<28````6UU!7$%=PV:0#[9#
M%(3`#X0A____/"X/A3?___^`>Q4`#X0/____9I#I)O___P\?`.C#_O__#Q\`
MZXYF9F9F9BX/'X0``````%532(/L"(L]9)0@`.BOW___BSU9E"``2(N`P```
M`$B+:`CHF=___XL]0Y0@``^VF)T```#HA]___TB+0`B#XW\/MT`@P>`'"=AF
MB44"BST=E"``Z&C?__^+/1*4(`!(BX#`````2(M8".A2W___,=*^,UM``$B)
MQ^@SW___BSWMDR``2(E#*.@TW___BSW>DR``2(N`P````$B+6`CH'M___TB+
M@(@&``"+/<&3(`!(B4,PZ`C?__^+/;*3(`!(BX#`````2(M8".CRWO__,=)(
M@[C(`0```'09BSV0DR``Z-O>__](BX#(`0``2(N0J````(L]=Y,@`$B)4SCH
MOM[__TB+@,````"+/6&3(`!(BT`(2,=`0`````#HH-[__TB+@,````"+/4.3
M(`!(BT`(2,=`(`````#H@M[__XL]+),@`$B+@,````!(BU@(Z&S>__](BX"`
M`P``2(E#2$B#Q`A;7<-F+@\?A```````4TB)^XL]]I(@`.A!WO__2(V0X`$`
M`$B)WK\!````Z(W?__^%P'0),<!;PP\?1```BSW*DB``Z!7>__^+@/@!```E
M`/```#T`0```=!V+/:V2(`#H^-W__XN`^`$``"4`\```/0"@``!UO4B)W[X"
M````Z.G>__^%P`^4P`^VP%O#9F9F9F9F+@\?A```````052Z_P\``$F)]%5(
MB?V_6EE``%-(@>P0$```2(GF9$B+!"4H````2(F$)`@0```QP.A:V___A<!^
M;HU(_TACV8`\'`!T6DACV$B)VKXO````2(GGZ,?<__](A<!T2HL]#)(@`.A7
MW?__2(G92(GB2(GN2(G'Z';>__](BX0D"!```&1(,P0E*````'4V2('$$!``
M`%M=05S##Q^``````(7)=:4/'T``BSW"D2``Z`W=__],B>)(B>Y(B<?HO]O_
M_^NWZ'C;__\/'X0``````$B#[`B+/9:1(`#HX=S__[EI64``NK`;0`"^<UE`
M`$B)QTB#Q`CI]MS__V8/'T0``$B#[`B+/6:1(`#HL=S__TB)Q^BY____BSU3
MD2``Z)[<__]!N#-;0`!%,<FZT%-``$R)P;Z/64``2(G'2(/$".D,W?__9F9F
M+@\?A```````4TB!["`@``!D2(L$)2@```!(B80D&"```#'`Z$#:__]!N659
M0`!!B<"YI%E``#'`N@$0``"^`0```$B)Y^CNW?__A<!X:DB-M"00$```N@`0
M``!(B>?HY=G__X7`2(G#>$Z->`%(8__H$]S__TB%P'0^2&/;2(VT)!`0``!(
MB<=(B=KHN-O__\8$&`!(BY0D&"```&1(,Q0E*````'452('$("```%O##Q^$
M```````QP.O8Z#?:__\/'X``````Z3O___]F9BX/'X0``````$%5051)B?R_
MLEE``%532(GS2('L.!```&1(BP0E*````$B)A"0H$```,<!(C70D'.@K]___
MOB\```!,B>=(B<7H^]G__TB%P'0W3(GFO[M90``QP.@G^/__3(G@2(NT)"@0
M``!D2#,T)2@````/A3L!``!(@<0X$```6UU!7$%=PTR)Y^B'V?__2(G?OLA9
M0`!!B<7H)]S__TB)PP\?0`!(A=MTI8`[`+BP64``2`]$V$B%[7032(G>2(GO
MZ&_:__^%P`^$H````$B)W^@_V?__B<%(F$B-5`/_@#HO=1"0Q@(`2(/J`8/I
M`8`Z+W3Q08U$#0$]_P\```^/2____TB-?"0@0;G*64``28G8N>E:0`"Z`!``
M`+X!````,<!,B20DZ#G<__^+/2./(`#H;MK__TB-="0@2(V0X`$``+\!````
MZ&C8__^%P'4=BSW^CB``Z$G:__^+@/@!```E`/```#T`@```=!2^R%E``#'_
MZ$O;__](B</I(____TB-?"0@O@$```#H)-O__X7`==E(C70D(+^[64``Z.'V
M__](C7PD(.@WV?__Z:[^___H;=C__V9F9F8N#Q^$```````/M@](B?B$R708
M2(U7`6:0@/DO#[8*2`]$PDB#P@&$R77N\\-F9F8N#Q^$``````!(A?]32(G[
M="^`/P!T*N@-V/__2(U4`_](.=-R#.M'D$B#Z@%(.=IT!X`Z+W3RZRV`.B]U
M?P\?`+\"````Z'[9__](A<!T:;HN````9HD06\,/'X``````@#HO=`E(@^H!
M2#G3<O)(.=IU"NO##Q\`@#HO=0E(@^H!2#G3<O)(*=I(C4("2#T`$```=R-(
MB=Y(@\(!N0`0``"_H-)@`.A]V?__N*#28`!;PV8/'T0``#'`6\-;O\I90`#I
M,=C__Y!(@^Q(O\Q90`!D2(L$)2@```!(B40D.#'`2(L%8!8``$B)1"002(L%
M7!8``$B)1"082(L%6!8``$B)1"0@2(L%5!8``$B)1"0H#[<%4!8``&:)1"0P
M,<#H%/7__S'`O]590`#H"/7__S'`O]U90`#H_/3__S'`O^990`#H\/3__S'`
MO^U90`#HY/3__S'`O_U90`#HV/3__S'`O[)90`#HS/3__S'`OPE:0`#HP/3_
M_S'`OQ-:0`#HM/3__S'`OQU:0`#HJ/3__S'`O[M90`#HG/3__S'`OR=:0`#H
MD/3__S'`OS!:0`#HA/3__TB-="0,,<"_.UI``.BS\___2(7`=`](B<:_$UI`
M`#'`Z+_T__](C70D##'`OTQ:0`#HCO/__TB%P'0/2(G&OUY:0``QP.B:]/__
M2(UT)`PQP+]I6D``Z&GS__](A<!T/$B)QK^R64``,<#H=?3__S'`OI5:0`"_
M[5E``.AD]/__2(M$)#AD2#,$)2@```!U6DB#Q$C##Q^``````$B-="0,,<"_
M>5I``.@7\___2(7`=!)(B<:_"5I``#'`Z"/T___KK)!(C70D(;^*6D``N0H`
M``#SIG682(UT)"N_"5I``#'`Z/SS___KA>B5U?__#Q]$``"+!:J+(`"#^/]T
M!<,/'T``2(/L&#'`OPE:0`!(C70D#.BK\O__2(7`="8/MA`QP(32=`@QP(#Z
M,`^5P(D%;XL@`$B#Q!C#9BX/'X0``````#'`Z^=F9F8N#Q^$``````!(@^P(
MZ#?5__^)Q^C@U/__2(7`=`M(BP!(@\0(PP\?`#'`Z_1F9F8N#Q^$``````!!
M5T%628G^055!O:%:0`!!5%6]EUI``%-(@^QH2,=$)""A6D``2,=$)"B76D``
M3(UD)#!(QT0D,*1:0`!(QT0D.)I:0`!(QT0D0)]:0`!(QT0D2+%:0`!(QT0D
M4`````#K)F8/'T0``$B)Q^C`U___2(7`=%-(A>UT/$F+!"1)B>U)@\0(2(G%
M2(UT)!PQP$R)[^BI\?__2(7`2(G#3(GV=`6`.`!UP4R)[S'`Z*_R__](A>UU
MQ$B#Q&A;74%<05U!7D%?PP\?`$R)]^@@U/__2(G?28G'Z!74__])C7P'`NBK
MU?__2(D<)$F)QTB)QT&YR%E``$V)\+GI6D``2,?"_____[X!````,<#H,-?_
M_TR)_DR)[S'`Z$/R___KDI!!5T%6055!5$F)_+^R64``55-(@>R8@0``9$B+
M!"4H````2(F$)(B!```QP$B-="0\2,=$)$#(6D``2,=$)$BP64``2,=$)%``
M````2,>$)(````!>6D``2,>$)(@```!76D``2,>$))````#-6D``2,>$))@`
M``!T6D``2,>$)*````#56D``2,>$)*@`````````2,=$)&"\6D``2,=$)&C9
M6D``2,=$)'``````Z&SP__](A<!T"8`X``^%1@0``#'`Z.?]__](A<!(B<,/
MA%($``!(B=_H\]+__TB-?``!Z(G4__^`.P!)B<5(B<5T,F8/'T0``$0/M@-(
MB>\QP+GB6D``2,?"_____[X!````2(/#`4B#Q0+H`=;__X`[`'742(VL)(@`
M``"_7EI``.L2#Q]$``!(@\4(2(M]^$B%_W0[2(UT)#PQP.C/[___2(7`2(G#
M=-^`.`!TVDB)Q^BJ]?__A<!TSDB)W^@NT___2(7`2(G#=5]F#Q]$``!(BUPD
M0$B%VP^$6@$``(`[`+T!````=27I2P$```\?`$ACQ4B+7,1`2(7;#X0W`0``
M@\4!@#L`#X0K`0``2(G?Z$OU__^%P'372(G?Z,_2__](A<!(B<-TQTB)W^CO
MT?__3(GIBS%(@\$$C9;__O[^]]8A\H'B@("`@'3HB=;![A#WPH"````/1-9(
MC7$"2`]$S@#22(/9`TPIZ42-M`@$!```36/V3(GWZ$+3__]!N<I90`!(B<=(
MB<5)B=BYYUI``$C'PO____^^`0```#'`3(EL)`A(QP0D\%I``.B^U/__OL`!
M``!(B>_HL=#__X/X_W1\BSV6AR``Z.'2__](C9#@`0``2(GNOP$```#H+=3_
M_X7`#X2-````28L,)$B+/8*'(`!)B>BZJ%M``+X!````,<#H-M3__S'`2(N4
M)(B!``!D2#,4)2@````/A9T(``!(@<28@0``6UU!7$%=05Y!7\,/'P`QV^GJ
M_O__D.C[S___1(L(08/Y$0^$<O___TF+#"1(BST;AR``28GHNFA;0`"^`0``
M`#'`Z,_3__\QP.N7#Q\`BSWBAB``Z"W2__^+@/@!```E`/```#T`0```#X52
M____BSW!AB``Z`S2__^+F/P!``#HD=#__SG##X4T____BSVCAB``Z.[1__^+
M@/@!```E_P$``#W``0``#X43____3(GWZ.#1__](C70D/+^:6D``2(G#,<#H
M?.W__TB%P$B)QP^$Q0<``.CKT/__28L\)$B)QNC_]?__2(7`28G%#X2H!P``
M3(GOZ/O/__^#^`-^-DACT+_U6D``N04```!)C705_/.F=2"#^`0/A'H&``"#
MZ`1(F$&`?`7_+P^$:08``&8/'T0``#'`Z#GZ__^%P'46,?9,B>_H^]'__X7`
MB40D(`^%3P$``+Z56D``OPE:0``QP.C^[?__Z`G/__](QT0D"#-;0`")!"1!
MN<I90`!)B>BY#EM``$C'PO____^^`0```$B)WS'`Z*G2__]%,>3K3`\?0`#H
M:\[__X,X$75008/$`>B]SO__2,=$)!`S6T``B00D0;G*64``1(ED)`A)B>BY
M'%M``$C'PO____^^`0```$B)WS'`Z%C2__^^P`$``$B)W^A+SO__@_C_=*9(
MB>_H_LW__TB)WK^R64``,<#H3^W__TB)W^CG^?__2(G8Z;O]__\/'X``````
M2(G'2(E$)"#HR_G__TB+1"0@2(G'Z'[/___IE?W__[^\6D``O0$```#K%0\?
M1```2&/%@\4!2(M\Q&!(A?]T*TB-="0\,<#HS.O__TB%P'3?@#@`=-I(B<?H
M.L___TB%P$B)PW3*Z6+[__]`MPV[P5I``.EB^___N@(```!(Q\;N____B<=!
MB<;H2M'__TB-M"2``0``N@8```!$B??H)<___X"\)(`!````=0Z`O"2!`0``
M0P^$+04``(M\)"`QTC'VZ!#1__^XB:O-[TC'A"0``0```2-%9TC'A"08`0``
M=E0R$$B)A"0(`0``N/[<NIA(QX0D*`$```````!(B80D$`$``+CPX=+#2,>$
M)#`!````````2(F$)"`!``!(C80D.`$``,>$)'@!````````2(E$)"B0BWPD
M($B-M"2``0``N@"```#H>L[__X7`28G'08G$#XZ9`0``2(NT)"@!``!)8\>-
M%,9(.=9(B[0D,`$``'8$2(/&`4C!Z!U(B90D*`$``$@!\$B)A"0P`0``2&.$
M)'@!``"%P`^$1@$``+I`````2(V\!#@!``!(C;0D@`$``"G"03G700].UTQC
MZD&)U$R)ZNA:SO__BX0D>`$``$0!X(/X0(F$)'@!```/A5#___]$B?A(C;PD
M``$``$0IX$&)Q$B-A"2``0``20'%Z!_3__\/'X``````08/\/P^.I0```$6)
MYDV)[P\?A```````28L/2(V\)``!``!!@^Y`28/'0$B)C"0X`0``28M/R$B)
MC"1``0``28M/T$B)C"1(`0``28M/V$B)C"10`0``28M/X$B)C"18`0``28M/
MZ$B)C"1@`0``28M/\$B)C"1H`0``28M/^$B)C"1P`0``Z(S2__]!@_X_?X9!
M@^Q`1(GBP>H&B=#!X@9(@\`!02G42,'@!DD!Q4B+?"0H26/4N4@```!,B>[H
M-,W__T2)I"1X`0``Z5?^__\/'X``````3(VL)(`!``#I&____XM\)"#H6LS_
M_TR+I"0H`0``3(NL)#`!``!,B>!(P>@#@^`_C4@!2&/0QH04.`$``("#^3@/
MCW8"``"Z-P```$ACR3'V*<)(C;P,.`$``$ACTNC=R___3(GH2(V\)``!``!$
MB*PD<P$``$C!Z!A$B*0D=P$``$R-O"30````B(0D<`$``$R)Z$C!Z!!-C7<H
MB(0D<0$``$R)Z$R-K"2Q````2,'H"(B$)'(!``!,B>!(P>@8B(0D=`$``$R)
MX$C!Z!"(A"1U`0``3(G@38G\2,'H"(B$)'8!``#H5='__TB+A"0``0``2(G"
MB(0DLP```$C!ZAA$#[;"B)0DL````$B)PDC!ZA"(E"2Q````2(G"2(N$)`@!
M``!(P>H(B)0DL@```$B)PHB$)+<```!(P>H8B)0DM````$B)PDC!ZA"(E"2U
M````2(G"2(N$)!`!``!(P>H(B)0DM@```$B)PHB$)+L```!(P>H8B)0DN```
M`$B)PDC!ZA"(E"2Y````2(G"2(N$)!@!``!(P>H(B)0DN@```$B)PHB$)+\`
M``!(P>H8B)0DO````$B)PDC!ZA"(E"2]````2(G"2(N$)"`!``!(P>H(B)0D
MO@```$B)PHB$),,```!(P>H8B)0DP````$B)PDC!ZA"(E"3!````2(G"2,'J
M"(B4),(```#I$`````\?@`````!%#[9%`$F#Q0%,B><QP+GB6D``2,?"____
M_[X!````28/$`NCPS/__33GT==/&A"3X`````$C'1"0(,UM``$R)/"1!N<I9
M0`!)B>BY_UI``$C'PO____^^`0```$B)WS'`Z++,___I9_K__TV+9"0(387D
M#X2/^?__3(GGZ$?)__](@_@##X9]^?__28UT!/R_^EI``+D%````\Z9-#T3L
MZ6/Y__](8\FZ/P```#'V2(V\##@!```IPDACTNAGR?__2(V\)``!``#H6L__
M_TB-E"0X`0``N0<````QP$B)U_-(J^EC_?__@+PD@@$``$$/A<7Z__^`O"2#
M`0``0P^%M_K__X"\)(0!``!(#X6I^O__@+PDA0$``$4/A9OZ__]$BW0D(+H"
M````2,?&QO___T2)]^B?R___2(VT)(`!``"Z*0```$2)]^AZR?__2(V$)(`!
M``!(QT0D"#-;0`!(B00DZ=K^___H:\C__TV++"3I3_C__V:0055!5%532(/L
M&(L]@'X@`.C+R?__2(UT)`S&@)D````!O^U90``QP.ASY?__2(7`=`F`.#$/
MA)4"```QP.BN\/__BSU(?B``Z)/)__^Y"P```+H!````OBU;0`!(B<?H',G_
M_TB%P`^$O````(,];(X@``%(BT`03(MH*`^.IP```+T(````,=OK,@\?1```
M28MT)!!(BP4\CB``2(L\*.C+R/__A<!U;X/#`8L%+HX@`$B#Q0B-4P$YPGUA
MBSW-?2``Z!C)__\QR8G:3(GN2(G'Z/G)__](A<!T/$R+($&+1"0,)0`$(``]
M``0``'2@BSV:?2``Z.7(__],B>:Y`@```#'22(G'Z+/'__](B<;K@V8/'T0`
M`(L%PHT@`(U0_SG:#X0_`0``BSUA?2``Z*S(__^Y!````+H!````OC);0`!(
MB<?H-<C__TB%P$B)PW0S2(M`$(L],WT@`$B+*.A[R/__NC1;0`!(B<=(B>[H
M*\?__TB+0Q!(BQCV0PY`#X4J`0``BST$?2``Z$_(__^Y!````+H!````OCE:
M0`!(B<?HV,?__TB%P$B)Q70]2(UT)`PQP+^[64``Z-_C__](A<!(B<,/A*,!
M``!(BT40BSVY?"``3(L@Z`'(__](B=I(B<=,B>;HL\;__XL]G7P@`.CHQ___
MBSV2?"``QH"9`````.C6Q___2(UT)`Q(QX!8!P```````+^R64``,<#H>N/_
M_TB%P$B)PTB)!;6,(``/A*\```"^P`$``$B)Q^A:Q?__@_@1=`R-4`&#^@$/
MAY8!``!(@\086UU!7$%=PV8/'T0``(/X`0^.N/[__[L!````9BX/'X0`````
M`(L]"GP@`(/#`>A2Q___3(GN2(G'Z"?%__\Y'4&,(`!_W^F#_O__9BX/'X0`
M`````(L]VGL@`.@EQ___2(G>2(G'Z'K'___IN_[__P\?1```@'@!``^$:/W_
M_V8/'T0``.E6_?__#Q\`2(L]Z8L@`.B,\?__2(7`2(D%ZHL@``^$WP```$B+
M11!,BR7)BR``2(L8BT,,)0`$(``]``0```^%F0```$B+>Q!,B>;H[\?__T&)
MQ$B+11!(BQB+4PR!X@`$(`"!^@`$``!U4$B+4Q!(BP6!BR``1(GAORA<0`!(
MBS`QP.B7QO__#Q^``````$B+!6&+(`"+/1-[(`!,BR!(BT402(L8Z%3&__],
MB>9(B=_HB>C__^E1_O__BSWN>B``Z#G&__\QTKD"````2(G>2(G'Z`?%__](
MB<+KDHL]S'H@`.@7QO__N0(```!(B<<QTDB)WNCEQ/__2(G'Z4;___^_`%Q`
M`.@3QO__B<%(BP7BBB``2(G:OU!<0`!(BS`QP.CXQ?__#Q^$``````!52(G]
M4TB#[`CH$NS__P^V"$B)PX3)=!I(C5`!#Q]``(#Y+P^V"D@/1-I(@\(!A,EU
M[C'`Z(?N__^%P'0=2(7M=!B`?0``=!*^\%I``$B)W^@KQ___2#G8=`=(@\0(
M6UW#2(/$"$B)[UM=Z5'D__^02(/L"(L]!GH@`.A1Q?__OO____](B<?H9,3_
M_XL][GD@`.@YQ?__,=*^\#U``$B)QTB#Q`CIQL;__V8/'T0``$B-!;%Y(`!(
MA<!T#$B+#:5Y(`#I.,3__S')Z_</'T``2(EL)-A,B60DX$B-+3=U(`!,C24H
M=2``2(E<)-!,B6PDZ$R)="3P3(E\)/A(@^PX3"GE08G_28GV2,']`TF)U3';
MZ`G"__](A>UT&@\?0`!,B>I,B?9$B?]!_Q3<2(/#`4@YZW7J2(M<)`A(BVPD
M$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,,/'X``````\\,``$B#[`A(@\0(
MPP````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!P97)L>'-I+F,`1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P
M<F]C+R5I+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)
M0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%2
M7U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%2
M1T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U0
M1$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X`4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,
M24)?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%
M`"4P,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE
M`"TM``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@
M;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C
M=&]R>0``````````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO
M/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````",A+W5S<B]B:6XO
M<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*
M<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T
M('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T
M<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E
M<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64[
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG
M="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I
M=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N
M"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE
M('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L
M;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI
M;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S
M('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@
M("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N
M9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D
M;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C
M97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN
M9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@
M("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@
M("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@
M/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO
M<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D
M<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@
M("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K
M(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@
M("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@
M("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA
M;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@
M979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%2
M7T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`]
M(&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#
M?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@
M("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@
M:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0
M051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP
M*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B
M=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C
M($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![
M>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@
M8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L
M(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B
M=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A
M8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@
M("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C
M($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@
M)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@
M("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE
M(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L
M;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@
M(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@
M7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@
M>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@
M("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O
M=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O
M?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@
M(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@
M;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B
M.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@
M("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@
M)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R
M:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B
M=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@
M("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@
M('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]
M"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY
M("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES
M="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%
M)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@
M:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@
M("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R
M971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N
M86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@
M("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@
M)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@
M)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@
M)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@
M(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U
M;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N
M9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C
M="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER
M92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE
M;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE
M.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@
M("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE
M<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP
M($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@
M("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*
M"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]
M"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6
M>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O
M;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@
M("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@
M('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@
M("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES
M(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!2
M3T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T
M:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T
M:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R
M;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%2
M1U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@
M("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@
M>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@
M>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@
M("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U
M;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]
M("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@
M("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@
M("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@
M("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I
M;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@
M("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A
M"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H
M)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER
M92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*
M"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@
M("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV
M(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ
M+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O
M=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD
M969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R
M(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@
M("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`[
M"B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U
M="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L
M"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@
M("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&
M2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D
M96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I
M9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B
M4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]
M?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@
M*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]
M96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U
M;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@
M>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(
M96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S
M*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N
M9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@
M("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@
M("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`
M24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX
M(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT
M<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N
M:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@
M9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y
M('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@
M=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F
M9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD
M("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@
M("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY
M("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@
M("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@
M("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@
M("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T
M("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@
M("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@
M("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@
M("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI
M('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D
M9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@
M("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@
M("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@
M("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E
M;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I
M=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D
M8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2![
M"B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G
M(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12([
M"B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@
M)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@
M(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]
M?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![
M>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@
M(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL
M92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I
M<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z
M.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@
M("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@
M("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@
M+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@
M("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@
M("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O
M(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U
M8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@
M"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R
M97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R
M97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U
M:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z
M.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@
M1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@
M("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@
M("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@
M(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@
M("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S
M(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I
M;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E
M=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T
M96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@
M;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@
M("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@
M(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@
M("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@
M("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]
M"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H
M(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N
M86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P
M<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@
M("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I
M9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@
M)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U
M9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@
M("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@
M("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@
M-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@
M("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M
M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@
M("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@
M("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@
M("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@
M("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92![
M"B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE
M;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="([
M"@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D
M9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I
M;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R
M;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]
M"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@
M(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*
M"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T
M7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@
M("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@
M)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*
M("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@
M("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@
M("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@
M("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92![
M"B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@
M("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I
M('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O
M<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO
M;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?
M96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@
M('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*
M("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@
M(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X
M:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R
M971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R
M:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P
M<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U
M:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T
M(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@
M=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE
M(#$P,3$*"E]?14Y$7U\*````````````````````P$,!&P,[]````!T```#(
M8O__0`$``"AG___H!0``-&G__Q`!```H:O__:`$``!B!__^X`0``V('__Q@"
M```X@O__.`(``$B$__^(`@``F(7__]@"```(A___"`,``)B'__\H`P``:(C_
M_V`#``"8B/__>`,``.B(__^0`P``J(G__[@#``"XB?__T`,``'B+__\0!```
MJ(O__R@$``!HC/__6`0``$B.__]X!```J([__Y@$``#8CO__N`0``/B/__\(
M!0``>)O__U@%``"(G___F`4``/B?___0!0``.*#__Q`&``!8H/__*`8``.B@
M__]0!@```````!0``````````7I2``%X$`$;#`<(D`$'$!0````<````'&C_
M_RH``````````````!0``````````7I2``%X$`$;#`<(D`$``"0````<````
M@&'__V`$````#A!&#AA*#PMW"(``/QH[*C,D(@````!,````1````+AH___I
M%@```$(.$(\"2`X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.R`0#QQ8..$$.
M,$$.*$(.($(.&$(.$$(."````````%P```"4````6'___[8`````0@X0CP)"
M#AB.`T(.((T$10XHC`5!#C"&!D$..(,'1`Y``G$*#CA##C!!#BA"#B!"#AA"
M#A!"#@A""UL..$$.,$$.*$(.($(.&$(.$$(."!P```#T````N'___U@`````
M00X0@P)'#B`"3@X000X(3````!0!``#X?___#0(```!"#A"/`D0.&(X#0@X@
MC01"#BB,!40.,(8&00XX@P='#E`#``$*#CA!#C!!#BA"#B!"#AA"#A!"#@A(
M"P````!,````9`$``+B!__]"`0```$(.$(T"0@X8C`-!#B"&!$0.*(,%1P[`
M`5$*#BA!#B!!#AA"#A!"#@A)"P+7"@XH00X@00X80@X00@X(0PL``"P```"T
M`0``N(+__V8!````00X0A@)!#AB#`T0.(`-=`0X800X000X(`````````!P`
M``#D`0``^(/__X$`````00X0@P)I"@X(1@L"4`X(-`````0"``!HA/__R```
M``!"#A",`DD.&(8#20X@@P1'#K`@`GD*#B!!#AA!#A!"#@A("P`````4````
M/`(```"%__\J`````$0.$&$."``4````5`(``!B%__]$`````$0.$'L."``D
M````;`(``%"%__^Y`````$$.$(,"1PZP0`*>"@X000X(20L`````%````)0"
M``#HA?__!0``````````````/````*P"``#@A?__LP$```!"#A"-`D(.&(P#
M20X@A@1!#BB#!4H.X"`"8@H.*$$.($$.&$(.$$(."$$+`````!0```#L`@``
M8(?__R0``````````````"P````$`P``>(?__[\`````1`X0@P("3`H."$@+
M`E$*#@A'"T,*#@A!"T$."````!P````T`P``"(C__]L!````1`Y0`WP!"@X(
M2`L`````'````%0#``#(B?__5`````!4#B!Q"@X(2PL````````<````=`,`
M``B*__\D`````$0.$%@*#@A$"P```````$P```"4`P``&(K__Q\!````0@X0
MCP)"#AB.`T4.((T$2`XHC`5!#C"&!D8..(,'1`Z@`0*>"@XX00XP00XH0@X@
M0@X80@X00@X(1`L`````3````.0#``#HBO__?@L```!"#A"/`D(.&(X#0@X@
MC01"#BB,!4D.,(8&00XX@P='#M"#`@/!`@H..$$.,$$.*$(.($(.&$(.$$(.
M"$0+```\````-`0``!B6__\(!````$(.$(T"0@X8C`-!#B"&!$$.*(,%1`Y`
M`U$""@XH00X@00X80@X00@X(1PL`````-````'0$``#HF?__;P````!!#A"&
M`D0.&(,#1`X@`E4*#AA!#A!!#@A!"T0.&$0.$$$."``````4````K`0``"":
M__\Z`````$0.$'$."``D````Q`0``#AA__\,`@```$$.$(,"1`Y``Y0!"@X0
M0PX(00L`````%````.P$```@FO__'```````````````)`````0%```HFO__
MB0````!*A@:,!68.0(,'C02.`X\"`E@."````!0````L!0``D)K__P(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````%`B0```````,")`````````````
M``````$``````````0`````````!``````````T"`````````0````````!<
M`@````````P``````````!M````````-`````````$190```````&0``````
M``#PS6```````!L`````````"``````````:`````````/C-8```````'```
M```````(`````````/7^_V\`````F`)````````%`````````)`-0```````
M!@````````"@`T````````H`````````*`4````````+`````````!@`````
M````%0````````````````````,``````````-!@```````"`````````'@&
M````````%``````````'`````````!<`````````B!1````````'````````
M`!`40```````"`````````!X``````````D`````````&`````````#^__]O
M`````)`30```````____;P`````"`````````/#__V\`````N!)`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````C.8````````````````````````````#8;0```````
M1AM```````!6&T```````&8;0```````=AM```````"&&T```````)8;0```
M````IAM```````"V&T```````,8;0```````UAM```````#F&T```````/8;
M0```````!AQ````````6'$```````"8<0```````-AQ```````!&'$``````
M`%8<0```````9AQ```````!V'$```````(8<0```````EAQ```````"F'$``
M`````+8<0```````QAQ```````#6'$```````.8<0```````]AQ````````&
M'4```````!8=0```````)AU````````V'4```````$8=0```````5AU`````
M``!F'4```````'8=0```````AAU```````"6'4```````*8=0```````MAU`
M``````#&'4```````-8=0```````YAU```````#V'4````````8>0```````
M%AY````````F'D```````#8>0```````1AY```````!6'D```````&8>0```
M````=AY```````"&'D```````)8>0```````IAY```````"V'D```````,8>
M0```````UAY```````#F'D```````/8>0```````!A]````````6'T``````
M`"8?0```````-A]```````!&'T```````%8?0```````9A]```````!V'T``
M``````````````````````````#_____`````)A<0```````1T-#.B`H56)U
M;G1U+TQI;F%R;R`T+C@N,BTQ=6)U;G1U,2D@-"XX+C(`1T-#.B`H56)U;G1U
M+TQI;F%R;R`T+C<N,RTW=6)U;G1U,RD@-"XW+C,``"YS:'-T<G1A8@`N:6YT
M97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S
M:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R
M`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A
M<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M``````````````````````````````````````````L````!`````@``````
M```X`D```````#@"````````'`````````````````````$`````````````
M```````3````!P````(`````````5`)```````!4`@```````"``````````
M```````````$````````````````````(0````<````"`````````'0"0```
M````=`(````````D````````````````````!````````````````````#0`
M``#V__]O`@````````"8`D```````)@"````````!`$````````%````````
M``@````````````````````^````"P````(`````````H`-```````"@`P``
M`````/`)````````!@````$````(`````````!@`````````1@````,````"
M`````````)`-0```````D`T````````H!0```````````````````0``````
M`````````````$X```#___]O`@````````"X$D```````+@2````````U```
M```````%``````````(``````````@````````!;````_O__;P(`````````
MD!-```````"0$P```````(``````````!@````(````(````````````````
M````:@````0````"`````````!`40```````$!0```````!X``````````4`
M````````"``````````8`````````'0````$`````@````````"(%$``````
M`(@4````````>`8````````%````#`````@`````````&`````````!^````
M`0````8``````````!M`````````&P```````!H````````````````````$
M````````````````````>0````$````&`````````"`;0```````(!L`````
M``!@!```````````````````$``````````0`````````(0````!````!@``
M``````"`'T```````(`?````````PCD``````````````````!``````````
M``````````"*`````0````8`````````1%E```````!$60````````D`````
M```````````````$````````````````````D`````$````"`````````%!9
M0```````4%D````````(7P``````````````````"```````````````````
M`)@````!`````@````````!8N$```````%BX````````]```````````````
M``````0```````````````````"F`````0````(`````````4+E```````!0
MN0```````'0%```````````````````(````````````````````L`````X`
M```#`````````/#-8```````\,T````````(````````````````````"```
M`````````````````+P````/`````P````````#XS6```````/C-````````
M"`````````````````````@```````````````````#(`````0````,`````
M`````,Y@````````S@````````@````````````````````(````````````
M````````S0````8````#``````````C.8```````",X```````#P`0``````
M``8`````````"``````````0`````````-8````!`````P````````#XSV``
M`````/C/````````"`````````````````````@`````````"`````````#;
M`````0````,``````````-!@````````T````````$`"````````````````
M```(``````````@`````````Y`````$````#`````````$#28```````0-(`
M```````@````````````````````"````````````````````.H````(````
M`P````````!@TF```````&#2````````:!```````````````````"``````
M``````````````#O`````0```#````````````````````!@T@```````%0`
M```````````````````!``````````$``````````0````,`````````````
M````````````M-(```````#X`````````````````````0``````````````
$````````
